/***************************************************************************
 *   NGT (Neopontec Gaming Toolkit		      			   *
 *   Distributed under the terms of the GNU LGPL License		   *
 *   Copyright (C) 2005 by Hector Blanco de Frutos                         *
 *   hectorblanco@neopontec.com                                            *
 *   Refer to the LICENSE file to read the full license agreement          *
 ***************************************************************************/
 
 /**************************************************************************
  * This code part was originaly taken from the SDL GFX tutorials at 
  * http://cone3d.gamedev.net , developed by Marius Andra
  **************************************************************************/
  
#ifndef _SPRITES_H_
	#define _SPRITES_H_
// The sprite helper structure
struct NGT_SpriteFrame
{
  SDL_Surface *image;
  int pause;
};

// The base structure for sprites
//!  NGT SpriteBase class 
/*!
  This class provides basic functions and objects to manage sprite units.
*/
class NGT_SpriteBase
{
  public:
  //! Initialize the sprite base.
  int init(char *dir);

  NGT_SpriteFrame *mAnim;
  int mBuilt;
  //! Number of frames
  int mNumframes;
  //! Width
  int mW;
  //! Height
  int mH;
};

//!  NGT Sprite class 
/*!
  This class provides basic functions and objects to manage and draw a sprite.
*/
class NGT_Sprite
{
  public:
  NGT_Sprite() {}
  ~NGT_Sprite() {};
  //! Initialize the sprite.
  int init(NGT_SpriteBase *base, SDL_Surface *screen);
  //! Draw the sprite
  void draw();
  void clearBG();
  void updateBG();
  //! Set the number of the current frame.
  void setFrame(int nr) { mFrame = nr; }
  //! Get the number of the current frame.
  int getFrame() { return mFrame; }
	
  //! Set the speed value for the animation
  void setSpeed(float nr) { mSpeed = nr; }
  //! Get the current speed of the animation
  float getSpeed() { return mSpeed; }

  //! Toggle between Stop or Play the animation.
  void toggleAnim() { mAnimating = !mAnimating; }
  //! Start playing the animation
  void startAnim() { mAnimating = 1; }
  //! Stop playing tha animation
  void stopAnim() { mAnimating = 0; }
  //! Go to the first frame of the animation.
  void rewind() { mFrame = 0; }

  //! Increment the 'x' coordinate of the sprite.
  void xadd(int nr) { mX+=nr; }
  //! Increment the 'y' coordinate of the sprite.
  void yadd(int nr) { mY+=nr; }
  //! Set the 'x' coordinate of the sprite.
  void xset(int nr) { mX=nr; }
  //! Set the 'y' coordinate of the sprite.
  void yset(int nr) { mY=nr; }
  //! Set both the 'x' and 'y' coordinates of the sprite.
  void set(int xx, int yy) { mX=xx; mY=yy; }
  
  //! Get the 'x' coordinate of the sprite.
  float getx() {return mX;}
  //! Get the 'y' coordinate of the sprite.
  float gety() {return mY;}
  //! Get the width of the sprite.
  int getw() {return mSpriteBase->mAnim[0].image->w;}
  //! Get the height of the sprite.
  int geth() {return mSpriteBase->mAnim[0].image->h;}
  
  private:
  int mFrame;
  int mX, mY, mOldX, mOldY;
  int mAnimating;
  int mDrawn;
  float mSpeed;
  long mLastupdate;
  NGT_SpriteBase *mSpriteBase;
  SDL_Surface *mBackreplacement;
  SDL_Surface *mScreen;
};

//!  NGT Sprite_Collide function 
/*!
  This function detects the collision of two sprites.
*/
short int Sprite_Collide(NGT_Sprite &object1, NGT_Sprite &object2);

#endif //_SPRITES_H_

