/***************************************************************************
 *   NGT (Neopontec Gaming Toolkit		      			   *
 *   Distributed under the terms of the GNU LGPL License		   *
 *   Copyright (C) 2005 by Hector Blanco de Frutos                         *
 *   hectorblanco@neopontec.com                                            *
 *   Refer to the LICENSE file to read the full license agreement          *
 ***************************************************************************/
 
#ifndef VIDEO_FONTS_H_
#define VIDEO_FONTS_H_
	
	// Text drawing effects
	#define TEXT_NONE 0
	#define TEXT_BLENDED 1
	#define TEXT_SHADED 2
	
	#include "../ngt.h"
	#include <string>
	
	using namespace std;

//!  NGT Font class 
/*!
  This class provides basic functions and objects to manage and draw fonts.
*/
	class NGT_Font{
		public:
			//! Path (relative or absolute) to the ttf font file.
			string filename;
			//! Size of the font.
			int size;
			//! 'Drawing mode.
			/*!
			  Available modes:\n
			  
			  TEXT_NONE = Draw the text as a solid, without any filter.\n
			  TEXT_BLENDED = Draw the text with a blend effect. Removes aliasing. May be slow.\n
			 */
			int mode;
			//! X coordinate for drawing.
			int x;
			//! Y coordinate for drawing.
			int y;
			//! Color of the font.
			SDL_Color color;
			//! Draws a text into screen, specifying all the parametres.
			void draw(string text, SDL_Surface *screen, int draw_x, int draw_y);
			//! Draws a text into screen, using the object attributes.
			void draw(string text, SDL_Surface *scr);
			//! Frees memory closing the loaded font.
			void free() { TTF_CloseFont(font); };
			// Constructors
			NGT_Font() {};
			//! Constructor, with two attributes to initialize.
			NGT_Font(string filename, int size);
			//! Loads a font, passing the path to the file, and the size for drawing
			int LoadTTF(string filename, int size);
			//! Loads the font. Uses the public attributes of the class.
			int LoadTTF();
		private:
			//! Where the font is stored when loaded.
			TTF_Font *font;
	};

#endif /*VIDEO_FONTS_H_*/
